==> openGion_dev_5.7.2.2.zip: opengion/uap/webapps/gf/src/org/opengion/plugin/column/Editor_RADIO.java <==
/*
 * Copyright (c) 2009 The openGion Project.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.opengion.plugin.column;

import org.opengion.hayabusa.common.HybsSystem;
import org.opengion.hayabusa.db.AbstractEditor;
import org.opengion.hayabusa.db.CellEditor;
import org.opengion.hayabusa.db.DBColumn;
import org.opengion.hayabusa.db.Selection;
import org.opengion.hayabusa.db.Selection_RADIO;
import org.opengion.fukurou.util.Attributes;
import org.opengion.fukurou.util.TagBuffer;
import org.opengion.fukurou.util.XHTMLTag;

/**
 * RADIO エディターは、カラムのデータをコードリソースに対応したラジオボタンで編集する
 * 場合に使用するクラスです。
 * ラジオボタンは、ラベルがない状態で表示される為、運用時には、ラベルに
 * 値(選択肢のラベル)を作成して、columnEditor 等で登録して置いてください。
 *
 * 一覧検索明細登録画面等で、ラベル表示が必要な場合は、編集パラメータに、"useLabel"と
 * 記述しておくことで、ラベルを出力することが可能です。
 *
 * このエディタはeventColumnに対応していません。
 *
 *  カラムの表示に必要な属性は, DBColumn オブジェクト より取り出します。
 * このクラスは、DBColumn オブジェクト毎に１つ作成されます。
 *
 * @og.rev 3.5.1.0 (2003/10/03) 新規作成
 * @og.group データ編集
 *
 * @version  4.0
 * @author	 Kazuhiko Hasegawa
 * @since    JDK5.0,
 */
public class Editor_RADIO extends AbstractEditor {
	//* このプログラムのVERSION文字列を設定します。	{@value} */
	private static final String VERSION = "4.3.3.0 (2008/10/01)" ;

	private final Selection	selection ;
	private final boolean writable ;
	private final boolean useLabel ; // 4.3.3.0 (2008/10/01)

	/**
	 * デフォルトコンストラクター。
	 * このコンストラクターで、基本オブジェクトを作成します。
	 *
	 */
	public Editor_RADIO() {
		// 4.3.4.4 (2009/01/01)
//		super();
		selection = null;
		writable  = false;
		useLabel  = false; // 4.3.3.0 (2008/10/01)
	}

	/**
	 * コンストラクター。
	 *
	 * @og.rev 3.5.4.2 (2003/12/15) makeCodeSelection メソッドを CodeSelectionクラスに変更。
	 * @og.rev 3.5.5.7 (2004/05/10) SelectionFactory を使用して、オブジェクト作成
	 * @og.rev 4.0.0.0 (2005/01/31) SelectionFactory ではなく、直接 Selection_RADIO を作成。
	 * @og.rev 4.3.3.0 (2008/10/01) 編集パラメーターで明細表示時でもラベルが使えるように対応
	 *
	 * @param	clm	DBColumnオブジェクト
	 */
	private Editor_RADIO( final DBColumn clm ) {
	//	super( clm );
		name  = clm.getName();
		selection = new Selection_RADIO( clm.getCodeData() );	// 4.0.0 (2005/01/31)

		writable = clm.isWritable();

		attributes = new Attributes();
		attributes.addAttributes( clm.getEditorAttributes() );

		attributes.add( "class","RADIO" );			// (2003/10/08 修正分)
		tagBuffer.add( XHTMLTag.inputAttri( attributes ) );

		optAttr = attributes.get( "optionAttributes" );

		// 4.3.3.0 (2008/10/01)
		useLabel = ( "useLabel".equalsIgnoreCase( clm.getEditorParam() ) ) ? true : false;
	}

	/**
	 * 各オブジェクトから自分のインスタンスを返します。
	 * 自分自身をキャッシュするのか、新たに作成するのかは、各サブクラスの実装に
	 * まかされます。
	 *
	 * @param	clm	DBColumnオブジェクト
	 *
	 * @return	CellEditorオブジェクト
	 */
	public CellEditor newInstance( final DBColumn clm ) {
		return new Editor_RADIO( clm );
	}

	/**
	 * データの編集用文字列を返します。
	 *
	 * @param	value 入力値
	 *
	 * @return	データの編集用文字列
	 */
	@Override
	public String getValue( final String value ) {
		final String radio ;
		if( writable ) {
			radio = selection.getRadio( name,value,true );
		}
		else {
			radio = selection.getValueLabel( value );
		}

		TagBuffer tag = new TagBuffer( "pre" );
		tag.add( tagBuffer.makeTag() );
		tag.add( optAttr );		// 3.5.5.8 (2004/05/20)
		tag.setBody( radio );

		return tag.makeTag();
	}

	/**
	 * name属性を変えた、データ表示/編集用のHTML文字列を作成します。
	 * テーブル上の name に 行番号を付加して、名前_行番号 で登録するキーを作成し,
	 * リクエスト情報を１つ毎のフィールドで処理できます。
	 *
	 * @og.rev 3.5.5.0 (2004/03/12) 名前と行番号の区切り記号("__")を、HybsSystem.JOINT_STRING  に変更。
	 * @og.rev 3.5.5.5 (2004/04/23) changeOptionAttributes を廃止します。
	 * @og.rev 4.3.3.0 (2008/10/01) 編集パラメーターで明細表示時でもラベルが使えるように対応
	 *
	 * @param	row   行番号
	 * @param	value 入力値
	 *
	 * @return	データ表示/編集用の文字列
	 */
	@Override
	public String getValue( final int row,final String value ) {
		final String radio ;
		if( writable ) {
			// 4.3.3.0 (2008/10/01)
//			radio = selection.getRadio( name + HybsSystem.JOINT_STRING + row,value,false );
			radio = selection.getRadio( name + HybsSystem.JOINT_STRING + row,value,useLabel );
		}
		else {
			radio = selection.getRadioLabel( value );
		}

		TagBuffer tag = new TagBuffer( "pre" );
		tag.add( tagBuffer.makeTag() );
		tag.setBody( radio );
		tag.add( optAttr );		// 3.5.5.8 (2004/05/20)

		return tag.makeTag( row,value );
	}
}

==> openGion_dev_5.7.3.0.zip: opengion/uap/webapps/gf/src/org/opengion/plugin/column/Editor_RADIO.java <==
/*
 * Copyright (c) 2009 The openGion Project.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.opengion.plugin.column;

import org.opengion.hayabusa.common.HybsSystem;
import org.opengion.hayabusa.db.AbstractEditor;
import org.opengion.hayabusa.db.CellEditor;
import org.opengion.hayabusa.db.DBColumn;
import org.opengion.hayabusa.db.Selection;
// import org.opengion.hayabusa.db.Selection_RADIO;		// 5.7.3.0 (2014/02/07) SelectionFactory を使う様に変更
import org.opengion.hayabusa.db.SelectionFactory;		// 5.7.3.0 (2014/02/07)
import org.opengion.fukurou.util.Attributes;
import org.opengion.fukurou.util.TagBuffer;
import org.opengion.fukurou.util.XHTMLTag;

/**
 * RADIO エディターは、カラムのデータをコードリソースに対応したラジオボタンで編集する
 * 場合に使用するクラスです。
 * ラジオボタンは、ラベルがない状態で表示される為、運用時には、ラベルに
 * 値(選択肢のラベル)を作成して、columnEditor 等で登録して置いてください。
 *
 * 一覧検索明細登録画面等で、ラベル表示が必要な場合は、編集パラメータに、"useLabel"と
 * 記述しておくことで、ラベルを出力することが可能です。
 *
 * このエディタはeventColumnに対応していません。
 *
 *  カラムの表示に必要な属性は, DBColumn オブジェクト より取り出します。
 * このクラスは、DBColumn オブジェクト毎に１つ作成されます。
 *
 * @og.rev 3.5.1.0 (2003/10/03) 新規作成
 * @og.group データ編集
 *
 * @version  4.0
 * @author	 Kazuhiko Hasegawa
 * @since    JDK5.0,
 */
public class Editor_RADIO extends AbstractEditor {
	//* このプログラムのVERSION文字列を設定します。	{@value} */
	private static final String VERSION = "4.3.3.0 (2008/10/01)" ;

	private final Selection	selection ;
	private final boolean writable ;
	private final boolean useLabel ; // 4.3.3.0 (2008/10/01)

	/**
	 * デフォルトコンストラクター。
	 * このコンストラクターで、基本オブジェクトを作成します。
	 *
	 */
	public Editor_RADIO() {
		// 4.3.4.4 (2009/01/01)
//		super();
		selection = null;
		writable  = false;
		useLabel  = false; // 4.3.3.0 (2008/10/01)
	}

	/**
	 * コンストラクター。
	 *
	 * @og.rev 3.5.4.2 (2003/12/15) makeCodeSelection メソッドを CodeSelectionクラスに変更。
	 * @og.rev 3.5.5.7 (2004/05/10) SelectionFactory を使用して、オブジェクト作成
	 * @og.rev 4.0.0.0 (2005/01/31) SelectionFactory ではなく、直接 Selection_RADIO を作成。
	 * @og.rev 4.3.3.0 (2008/10/01) 編集パラメーターで明細表示時でもラベルが使えるように対応
	 * @og.rev 5.7.3.0 (2014/02/07) SelectionFactory 対応
	 *
	 * @param	clm	DBColumnオブジェクト
	 */
	private Editor_RADIO( final DBColumn clm ) {
	//	super( clm );
		name  = clm.getName();
		// 5.7.3.0 (2014/02/07) SelectionFactory 対応
//		selection = new Selection_RADIO( clm.getCodeData() );	// 4.0.0 (2005/01/31)
		selection = SelectionFactory.newSelection( "RADIO" , clm.getCodeData() );

		writable = clm.isWritable();

		attributes = new Attributes();
		attributes.addAttributes( clm.getEditorAttributes() );

		attributes.add( "class","RADIO" );			// (2003/10/08 修正分)
		tagBuffer.add( XHTMLTag.inputAttri( attributes ) );

		optAttr = attributes.get( "optionAttributes" );

		// 4.3.3.0 (2008/10/01)
		useLabel = ( "useLabel".equalsIgnoreCase( clm.getEditorParam() ) ) ? true : false;
	}

	/**
	 * 各オブジェクトから自分のインスタンスを返します。
	 * 自分自身をキャッシュするのか、新たに作成するのかは、各サブクラスの実装に
	 * まかされます。
	 *
	 * @param	clm	DBColumnオブジェクト
	 *
	 * @return	CellEditorオブジェクト
	 */
	public CellEditor newInstance( final DBColumn clm ) {
		return new Editor_RADIO( clm );
	}

	/**
	 * データの編集用文字列を返します。
	 *
	 * @param	value 入力値
	 *
	 * @return	データの編集用文字列
	 */
	@Override
	public String getValue( final String value ) {
		final String radio ;
		if( writable ) {
			radio = selection.getRadio( name,value,true );
		}
		else {
			radio = selection.getValueLabel( value );
		}

		TagBuffer tag = new TagBuffer( "pre" );
		tag.add( tagBuffer.makeTag() );
		tag.add( optAttr );		// 3.5.5.8 (2004/05/20)
		tag.setBody( radio );

		return tag.makeTag();
	}

	/**
	 * name属性を変えた、データ表示/編集用のHTML文字列を作成します。
	 * テーブル上の name に 行番号を付加して、名前_行番号 で登録するキーを作成し,
	 * リクエスト情報を１つ毎のフィールドで処理できます。
	 *
	 * @og.rev 3.5.5.0 (2004/03/12) 名前と行番号の区切り記号("__")を、HybsSystem.JOINT_STRING  に変更。
	 * @og.rev 3.5.5.5 (2004/04/23) changeOptionAttributes を廃止します。
	 * @og.rev 4.3.3.0 (2008/10/01) 編集パラメーターで明細表示時でもラベルが使えるように対応
	 *
	 * @param	row   行番号
	 * @param	value 入力値
	 *
	 * @return	データ表示/編集用の文字列
	 */
	@Override
	public String getValue( final int row,final String value ) {
		final String radio ;
		if( writable ) {
			// 4.3.3.0 (2008/10/01)
//			radio = selection.getRadio( name + HybsSystem.JOINT_STRING + row,value,false );
			radio = selection.getRadio( name + HybsSystem.JOINT_STRING + row,value,useLabel );
		}
		else {
			radio = selection.getRadioLabel( value );
		}

		TagBuffer tag = new TagBuffer( "pre" );
		tag.add( tagBuffer.makeTag() );
		tag.setBody( radio );
		tag.add( optAttr );		// 3.5.5.8 (2004/05/20)

		return tag.makeTag( row,value );
	}
}
